Generator class
A generator generates documentation for a given package.
Generators can generate documentation in different formats: HTML, JSON, etc.
Constructors
- Generator(GeneratorBackend _generatorBackend)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsLinkValidation → bool
-
no setter
-
writtenFiles
→ Set<
String> -
no setter
Methods
-
generate(
PackageGraph? packageGraph) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateGeneratedLinks(
PackageGraph packageGraph, DartdocOptionContext config, String origin, StreamController< String> onCheckProgress) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited