toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => switch (this) {
  accessor => 'accessor',
  constant => 'constant',
  constructor => 'constructor',
  class_ => 'class',
  dynamic => 'dynamic',
  enum_ => 'enum',
  extension => 'extension',
  extensionType => 'extension type',
  function => 'function',
  library => 'library',
  method => 'method',
  mixin => 'mixin',
  never => 'Never',
  package => 'package',
  parameter => 'parameter',
  prefix => 'prefix',
  property => 'property',
  sdk => 'SDK',
  topic => 'topic',
  topLevelConstant => 'top-level constant',
  topLevelProperty => 'top-level property',
  typedef => 'typedef',
  typeParameter => 'type parameter',
};