createGeneratorOptions function
Implementation
List<DartdocOption> createGeneratorOptions(
PackageMetaProvider packageMetaProvider,
) {
var resourceProvider = packageMetaProvider.resourceProvider;
return [
DartdocOptionArgFile<List<String>>(
'footer',
[],
resourceProvider,
optionIs: OptionKind.file,
help:
'Paths to files with content to add to page footers, but possibly '
'outside of dedicated footer elements for the generator (e.g. '
'outside of <footer> for an HTML generator). To add text content '
'to dedicated footer elements, use --footer-text instead.',
mustExist: true,
splitCommas: true,
),
DartdocOptionArgFile<List<String>>(
'footerText',
[],
resourceProvider,
optionIs: OptionKind.file,
help:
'Paths to files with content to add to page footers (next to the '
'package name and version).',
mustExist: true,
splitCommas: true,
),
DartdocOptionArgFile<List<String>>(
'header',
[],
resourceProvider,
optionIs: OptionKind.file,
help: 'Paths to files with content to add to page headers.',
splitCommas: true,
),
DartdocOptionArgOnly<bool>(
'prettyIndexJson',
false,
resourceProvider,
help:
'Generates `index.json` with indentation and newlines. The file is '
'larger, but it\'s also easier to diff.',
negatable: false,
),
DartdocOptionArgFile<String?>(
'favicon',
null,
resourceProvider,
optionIs: OptionKind.file,
help: 'A path to a favicon for the generated docs.',
mustExist: true,
),
DartdocOptionArgOnly<String?>(
'relCanonicalPrefix',
null,
resourceProvider,
help:
'If provided, add a rel="canonical" prefixed with provided value. '
'Consider using if building many versions of the docs for public '
'SEO; learn more at https://goo.gl/gktN6F.',
),
];
}