Dartdoc class
Generates Dart documentation for all public Dart libraries in the given directory.
Constructors
- Dartdoc.fromContext(DartdocGeneratorOptionContext context, PackageBuilder packageBuilder)
-
Builds Dartdoc with a generator determined by
context.factory
Properties
- config → DartdocOptionContext
-
final
- generator ↔ Generator
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onCheckProgress
→ Stream<
String> -
no setter
- packageBuilder → PackageBuilder
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeGuarded(
) → void - Runs generateDocs function and properly handles the errors.
-
generateDocs(
) → Future< DartdocResults> - Generates Dartdoc documentation.
-
generateDocsBase(
) → Future< DartdocResults> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited